/*
 * CallEdgeLengthSettings.java
 *
 * Author: Pieter Deelen
 * Created: August 26, 2005, 4:57 PM
 *
 */

package tracevis.control.settings;

import javax.swing.SpinnerNumberModel;

import tracevis.visualization.functions.CallEdgeLengthFunction;
import tracevis.visualization.functions.Function;

/**
 * A configuration panel which allows the user the configure the "calls" length
 * function.
 * @author  Pieter Deelen
 */
public class CallEdgeLengthSettings extends FunctionSettings {
	private final CallEdgeLengthFunction callEdgeLengthFunction;

	/**
	 * Creates new form CallEdgeLengthSettings.
	 */
	public CallEdgeLengthSettings(CallEdgeLengthFunction callEdgeLengthFunction) {
		this.callEdgeLengthFunction = callEdgeLengthFunction;
		initComponents();
	}

	@Override
	public Function getFunction() {
		return callEdgeLengthFunction;
	}

	@Override
	public String getFunctionName() {
		return "Calls";
	}

	/** This method is called from within the constructor to
	 * initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is
	 * always regenerated by the Form Editor.
	 */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        java.awt.GridBagConstraints gridBagConstraints;

        basicLengthLabel = new javax.swing.JLabel();
        basicLengthSpinner = new javax.swing.JSpinner();
        fillerPanel = new javax.swing.JPanel();
        logarithmicCheckBox = new javax.swing.JCheckBox();

        setLayout(new java.awt.GridBagLayout());

        basicLengthLabel.setText("Basic Length");
        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 5, 5, 5);
        add(basicLengthLabel, gridBagConstraints);

        basicLengthSpinner.setModel(new SpinnerNumberModel(1, 1, 1000, 10));
        basicLengthSpinner.setValue(callEdgeLengthFunction.getBasicLength());
        basicLengthSpinner.addChangeListener(new javax.swing.event.ChangeListener() {
            @Override
			public void stateChanged(javax.swing.event.ChangeEvent evt) {
                basicLengthSpinnerStateChanged(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.fill = java.awt.GridBagConstraints.HORIZONTAL;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.insets = new java.awt.Insets(5, 5, 5, 5);
        add(basicLengthSpinner, gridBagConstraints);

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 2;
        gridBagConstraints.gridwidth = 2;
        gridBagConstraints.gridheight = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.fill = java.awt.GridBagConstraints.BOTH;
        gridBagConstraints.weightx = 1.0;
        gridBagConstraints.weighty = 1.0;
        add(fillerPanel, gridBagConstraints);

        logarithmicCheckBox.setSelected(callEdgeLengthFunction.isLogarithmic());
        logarithmicCheckBox.setText("Logarithmic?");
        logarithmicCheckBox.addActionListener(new java.awt.event.ActionListener() {
            @Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
                logarithmicCheckBoxActionPerformed(evt);
            }
        });

        gridBagConstraints = new java.awt.GridBagConstraints();
        gridBagConstraints.gridx = 0;
        gridBagConstraints.gridy = 1;
        gridBagConstraints.gridwidth = java.awt.GridBagConstraints.REMAINDER;
        gridBagConstraints.anchor = java.awt.GridBagConstraints.WEST;
        gridBagConstraints.insets = new java.awt.Insets(5, 5, 5, 5);
        add(logarithmicCheckBox, gridBagConstraints);

    }
    // </editor-fold>//GEN-END:initComponents

	private void logarithmicCheckBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_logarithmicCheckBoxActionPerformed
		boolean logarithmic = logarithmicCheckBox.isSelected();
		callEdgeLengthFunction.setLogarithmic(logarithmic);
	}//GEN-LAST:event_logarithmicCheckBoxActionPerformed

	private void basicLengthSpinnerStateChanged(javax.swing.event.ChangeEvent evt) {//GEN-FIRST:event_basicLengthSpinnerStateChanged
		Integer basicLength = (Integer)basicLengthSpinner.getValue();
		callEdgeLengthFunction.setBasicLength(basicLength);
	}//GEN-LAST:event_basicLengthSpinnerStateChanged


    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JLabel basicLengthLabel;
    private javax.swing.JSpinner basicLengthSpinner;
    private javax.swing.JPanel fillerPanel;
    private javax.swing.JCheckBox logarithmicCheckBox;
    // End of variables declaration//GEN-END:variables

}
