/*
 * VertexSizeFunctionSelector.java
 *
 * Author: Pieter Deelen
 * Created: September 26, 2005, 1:46 PM
 *
 */

package tracevis.control.settings;

import java.awt.CardLayout;

import tracevis.visualization.structure.StructuralView.SelectedVertexSizeFunction;
import tracevis.visualization.structure.VertexSizeSettings;

/**
 *
 * @author  Pieter Deelen
 */
public class VertexSizeFunctionSelector extends javax.swing.JPanel {
	private final CallsReceivedVertexSizeSettings callsReceivedPanel;
	private final CallsSentVertexSizeSettings callsSentPanel;
	private final InstanceVertexSizeSettings instancePanel;

	/**
	 * Creates new form VertexSizeFunctionSelector.
	 */
	public VertexSizeFunctionSelector(VertexSizeSettings settings) {
		initComponents();

		callsReceivedPanel = new CallsReceivedVertexSizeSettings(settings.getCallsReceivedSettings());
		settingsPanel.add(callsReceivedPanel, SelectedVertexSizeFunction.CALLS_RECEIVED.toString());
		functionComboBox.addItem(SelectedVertexSizeFunction.CALLS_RECEIVED);

		callsSentPanel = new CallsSentVertexSizeSettings(settings.getCallsSentSettings());
		settingsPanel.add(callsSentPanel, SelectedVertexSizeFunction.CALLS_SENT.toString());
		functionComboBox.addItem(SelectedVertexSizeFunction.CALLS_SENT);

		instancePanel = new InstanceVertexSizeSettings(settings.getInstanceSettings());
		settingsPanel.add(instancePanel, SelectedVertexSizeFunction.INSTANCE.toString());
		functionComboBox.addItem(SelectedVertexSizeFunction.INSTANCE);

		SelectedVertexSizeFunction selected = settings.getSelectedFunction();
		functionComboBox.setSelectedItem(selected);
		CardLayout cardLayout = (CardLayout)(settingsPanel.getLayout());
		cardLayout.show(settingsPanel, selected.toString());
	}

	public VertexSizeSettings getSettings() {
		return new VertexSizeSettings(
			callsReceivedPanel.getSettings(),
			callsSentPanel.getSettings(),
			instancePanel.getSettings(),
			(SelectedVertexSizeFunction)functionComboBox.getSelectedItem()
		);
	}

	/** This method is called from within the constructor to
	 * initialize the form.
	 * WARNING: Do NOT modify this code. The content of this method is
	 * always regenerated by the Form Editor.
	 */
    // <editor-fold defaultstate="collapsed" desc=" Generated Code ">//GEN-BEGIN:initComponents
    private void initComponents() {
        selectorPanel = new javax.swing.JPanel();
        functionComboBox = new javax.swing.JComboBox<SelectedVertexSizeFunction>();
        settingsPanel = new javax.swing.JPanel();

        setLayout(new java.awt.BorderLayout());

        setBorder(new javax.swing.border.TitledBorder("Vertex Size"));
        selectorPanel.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.LEFT));

        functionComboBox.addActionListener(new java.awt.event.ActionListener() {
            @Override
			public void actionPerformed(java.awt.event.ActionEvent evt) {
                functionComboBoxActionPerformed(evt);
            }
        });

        selectorPanel.add(functionComboBox);

        add(selectorPanel, java.awt.BorderLayout.NORTH);

        settingsPanel.setLayout(new java.awt.CardLayout());

        add(settingsPanel, java.awt.BorderLayout.CENTER);

    }
    // </editor-fold>//GEN-END:initComponents

	private void functionComboBoxActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_functionComboBoxActionPerformed
		SelectedVertexSizeFunction selected = (SelectedVertexSizeFunction)functionComboBox.getSelectedItem();

		CardLayout cardLayout = (CardLayout)(settingsPanel.getLayout());
		cardLayout.show(settingsPanel, selected.toString());
	}//GEN-LAST:event_functionComboBoxActionPerformed


    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JComboBox<SelectedVertexSizeFunction> functionComboBox;
    private javax.swing.JPanel selectorPanel;
    private javax.swing.JPanel settingsPanel;
    // End of variables declaration//GEN-END:variables

}
