/*
 * ProgramListener.java
 *
 * Author: Pieter Deelen
 * Created: June 3, 2005, 11:16 AM
 *
 */

package tracevis.model.types;

import java.util.EventListener;


/**
 * A ProgramListener listens to the events generated by a Program.
 * @author Pieter Deelen
 */
public interface ProgramListener extends EventListener {
	/**
	 * Indicates that the trace has been loaded.
	 */
	void traceLoaded();

	/**
	 * Indicates that the trace has been filtered.
	 */
	void traceFiltered();

	/**
	 * Indicates that the current time has changed.
	 */
	void timeChanged();

	/**
	 * Indicates that a method has been entered.
	 * @param caller the ClassData of the calling class.
	 * @param callee the ClassData of the called class.
	 */
	void methodEntered(ClassData caller, ClassData callee);

	/**
	 * Indicates that a method has been exited.
	 * @param caller the ClassData of the calling class.
	 * @param callee the ClassData of the called class.
	 */
	void methodExited(ClassData caller, ClassData callee);
}
